# Routienen bezglich eines Planetenglobus unter Annahme der Ellipsoiditt des Krpers.
# Version: 09.12.1997
# Diese Library ist Bestandteil des AstroIx Programmpaketes
# Copyright (c) 1997 Xaman Ek Xols
# Autor: Wolfgang Pawlowski

# Eingabe: Abplattung, quatorradius, Breitengrad
# Ausgabe: Weglnge eines Lngengrades
proc laenge_1_grad {f a breitengr} {
  global const_pi  
  set e [expr sqrt(2 * $f - $f * $f)]
  set breite [expr ($const_pi * $breitengr) / 180.0]
  set zw [expr 1 - ($e * $e * sin($breite) * sin($breite))]
  set rp [expr ($a * cos($breite)) / sqrt($zw)]
  set lgrad [expr $rp * $const_pi / 180.0]
  if {abs($breitengr) == 90} {
        set lgrad 0
  }
  return $lgrad
}  

# Eingabe: Abplattung, quatorradius, Breitengrad
# Ausgabe: Weglnge eines Breitengrades
proc breite_1_grad {f a breitengr} {
  global const_pi  
  set e [expr sqrt(2 * $f - $f * $f)]
  set breite [expr ($const_pi * $breitengr) / 180.0]
  set zw [expr 1 - ($e * $e * sin($breite) * sin($breite))]
  set zw [expr pow( $zw, 1.5)]
  set rm [expr ($a * (1 - $e * $e)) / $zw]
  set bgrad [expr $rm * $const_pi / 180.0]
  return $bgrad
}

# Eingabe: Breite u. Lnge des 1.Ortes und des 2.Ortes, Abplattung, quatorradius
# Ausgabe: Strecke mit einem mglichen Fehler von 50 Metern
proc Strecke {br1 lae1 br2 lae2 f a}  {
  global const_pi  
  set fg [expr ($br1 + $br2) / 2]
  set fg [expr ($const_pi * $fg) / 180.0]
  set g  [expr ($br1 - $br2) / 2]
  set g  [expr ($const_pi * $g) / 180.0]
  set l  [expr ($lae1 - $lae2) / 2]
  set l  [expr ($const_pi * $l) / 180.0]
  set s  [expr (sin($g)*sin($g)*cos($l)*cos($l) + cos($fg)*cos($fg)*sin($l)*sin($l))]
  set c  [expr (cos($g)*cos($g)*cos($l)*cos($l) + sin($fg)*sin($fg)*sin($l)*sin($l))]
  set wg [expr atan(sqrt($s / $c))]
  set r  [expr sqrt($s*$c) / $wg]
  set d  [expr 2 * $wg * $a]
  set h1 [expr (3*$r - 1) / (2 * $c)]
  set h2 [expr (3*$r + 1) / (2 * $s)]
  set st [expr ($f*$h1*sin($fg)*sin($fg)*cos($g)*cos($g))]
  set st [expr $d * (1 + $st - $f*$h2*cos($fg)*cos($fg)*sin($g)*sin($g))]
  return $st
}
#Eingabe Abplattung, quatorradius, Breitengrad und Hhe . NN
proc rhosinbr {f a breitengr hoehe} {
  global const_pi  
  if {$hoehe == "x      "} {
    set hoehe 0
  }
  set breite [expr ($const_pi * $breitengr) / 180.0]
  set ab [expr 1.0 - $f]
  set u [expr atan($ab * tan($breite))]
  set out [expr $ab * sin($u) + ($hoehe / ($a * 1000)) * sin($breite)]
  return $out
}

#Eingabe Abplattung, quatorradius, Breitengrad und Hhe . NN
proc rhocosbr {f a breitengr hoehe} {
  global const_pi  
  if {$hoehe == "x      "} {
    set hoehe 0
  }
  set breite [expr ($const_pi * $breitengr) / 180.0]
  set ab [expr 1.0 - $f]
  set u [expr atan($ab * tan($breite))]
  set out [expr cos($u) + ($hoehe / ($a * 1000)) * cos($breite)]
  return $out
}

